<?php
namespace Ireca\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class ovacrs_contact_box extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ovacrs_contact_box';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact Box', 'ireca' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'ovatheme' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	// public function get_script_depends() {
	// 	return [ 'ireca' ];
	// }

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ireca' ),
			]
		);

			$this->add_control(
				'icon',
				[
					'label' => __( 'Icon', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					"default" => 'flaticon-alarm-clock',
				]
			);

			$this->add_control(
				'title',
				[
					'label' => __( 'Title', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( 'working hours', 'ireca' )
				]
			);

			$this->add_control(
				'items',
				[
					'label' => __( 'Items', 'ireca' ),
					'type' => Controls_Manager::REPEATER,
					'default' => [
						[
							'name' => __( 'Mon: 13:00-18:00', 'ireca' ),
							'label' => __( 'Name', 'ireca' ),
						],
						[
							'name' => __( 'Tue, Wed, Fri & Sat: 09:00-18:00', 'ireca' ),
							'label' => __( 'Name', 'ireca' ),
						],
					],
					'fields' => [
						[
							'name' => 'name',
							'label' => __( 'Name', 'ireca' ),
							'type' => Controls_Manager::TEXT,
							'default' => __( 'Mon: 13:00-18:00' , 'ireca' ),
							'dynamic' => [
								'active' => true,
							],
							'label_block' => true,
						]
					],
					'title_field' => '{{{ name }}}',
				]
			);

			$this->add_control(
				'show_line',
				[
					'label' => __( 'Show line', 'ireca' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'yes',
					'options' => [
						'yes' => __( 'Yes', 'ireca' ),
						'no'  => __( 'No', 'ireca' ),
						
					],
				]
			);


			

			$this->add_control(
				'class',
				[
					'label' => __( 'Class', 'ireca' ),
					'type' => Controls_Manager::TEXT,
				]
			);

		$this->end_controls_section();

		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		$html = '<div class="ovacrs_contact_box '.$settings['class'].' ">';

			$html .= '<div class="content">';

				$html .= '<i class="'.$settings['icon'].'"></i>';

				$html .= '<div class="title">'.$settings['title'].'</div>';

				foreach ( $settings['items'] as $index => $item ) :

		       		$html .= '<div class="item">'.$item['name'].'</div>';

		       endforeach;

		       $html .= $settings['show_line'] == 'yes' ? '<span class="line"></span>' : '';

			$html .= '</div>';

		$html .= '</div>';

		echo $html;
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {
		?>
		<div class="ovacrs_contact_box {{{ settings.class }}} ">

			<div class="content">

				<i class="{{{ settings.icon }}} "></i>

				<div class="title">{{{ settings.title }}}</div>

				<# _.each( settings.items, function( item, index ) {  #>

					<div class="item">{{{ item.name }}}</div>
					
				<# }); #>

				<# if( settings.show_line == 'yes' ){ #>
					
					<span class="line"></span>

				<# } #>

			</div>

		</div>
		<?php
	}
}
