<?php
namespace Ireca\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class ovacrs_img_skew extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ovacrs_img_skew';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Image Skew', 'ireca' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'ovatheme' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'ovacrs_img_skew' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ireca' ),
			]
		);

			$this->add_control(
				'title',
				[
					'label' => __( 'Title', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( 'Title', 'ireca' ),
				]
			);

			$this->add_control(
				'img',
				[
					'label' => __( 'Image', 'ireca' ),
					'type' => Controls_Manager::MEDIA,
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					
				]
			);
			
			$this->add_control(
				'align',
				[
					'label' => __( 'Align', 'ireca' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'left',
					'options' => [
						'left' => __( 'Left', 'ireca' ),
						'right'  => __( 'Right', 'ireca' ),
						
					],
				]
			);
			

			$this->add_control(
				'desc',
				[
					'label' => __( 'Description', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( 'For more information, please contact hotline', 'ireca' ),
				]
			);

			$this->add_control(
				'phone',
				[
					'label' => __( 'Phone', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( '54-344-4533-4', 'ireca' ),
				]
			);

			$this->add_control(
				'email',
				[
					'label' => __( 'Mail', 'ireca' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( 'email@company.com', 'ireca' ),
				]
			);

			$this->add_control(
				'class',
				[
					'label' => __( 'Class', 'ireca' ),
					'type' => Controls_Manager::TEXT,
				]
			);

		$this->end_controls_section();

		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		
      
	    $html = '<div class="img_skew '.$settings['class'].' '.$settings['align'].' " style="background: url( '.$settings['img']['url'].' ); ">';

	       $html .= '<div class="content" style="height: 400px;">';
	       	$html .= '<h3 class="title"><span>'.$settings['title'].'</span></h3>';
	       	$html .= '<div class="wrap_desc">';
	       		$html .= '<div class="desc">'.$settings['desc'].'</div>';
	       		$html .= '<div class="contact"><span class="phone">'.$settings['phone'].'</span><span class="email">'.$settings['email'].'</span></div>';
	       	$html .= '</div>';
	       $html .= '</div>';
	        
	    $html .= '</div>';

	    echo $html;

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {
		?>
		
    <div class="img_skew {{{ settings.class }}} {{{ settings.align }}} " style="background: url( {{{ settings.img.url }}} ) ">

	       <div class="content">
	       	<h3 class="title"><span>{{{ settings.title }}}</span></h3>
	       	<div class="wrap_desc">
	       		<div class="desc">{{{ settings.desc }}}</div>
	       		<div class="contact"><span class="phone">{{{ settings.phone }}} </span><span class="email">{{{ settings.email }}}</span></div>
	       	</div>
	       </div>
	        
	    </div>

		<?php
	}
}
