<?php

if ( !defined( 'ABSPATH' ) ) exit();

// ADD A PRODUCT TYPE **************************************/
add_filter( 'product_type_selector', 'ovacrs_add_custom_product_type', 10, 1 );
add_action( 'init', 'ovacrs_create_custom_product_type' );
// add_filter( 'product_type_options', 'ovacrs_rental_product_options', 8 );

function ovacrs_add_custom_product_type( $types ){
    $types[ 'ovacrs_car_rental' ] = esc_html__( 'Car Rental', 'ova-crs' );
    return $types;
}

function ovacrs_create_custom_product_type(){
    // declare the product class
    class WC_Product_Ovacrs_car_rental extends WC_Product{
        public function __construct( $product ) {
           $this->product_type = 'ovacrs_car_rental';
           parent::__construct( $product );
           // add additional functions here
        }
    }
}

// ADD CUSTOM FIELD PRODUCT TYPE **************************************/

// add the settings under ‘General’ sub-menu
add_action( 'woocommerce_product_options_general_product_data', 'ovacrs_add_custom_settings' );
add_action( 'woocommerce_process_product_meta', 'ovacrs_save_custom_settings' );

function ovacrs_add_custom_settings() {
    global $woocommerce, $post;
    include( OVACRS_PLUGIN_PATH.'/templates/ovacrs-custom-fields.php' );
}


// Save Custom Fields
function ovacrs_save_custom_settings( $post_id ) {
    $ovacrs_manage_store = $_POST['ovacrs_manage_store'] ? $_POST['ovacrs_manage_store'] : 'vehicle';
    update_post_meta( $post_id, 'ovacrs_manage_store', esc_attr( $ovacrs_manage_store ));

    $ovacrs_stock_quantity = isset( $_POST['ovacrs_stock_quantity'] ) ? $_POST['ovacrs_stock_quantity'] : 0;
    update_post_meta( $post_id, 'ovacrs_stock_quantity', esc_attr( $ovacrs_stock_quantity ));

    $ovacrs_regul_price_hour = isset( $_POST['ovacrs_regul_price_hour'] ) ? $_POST['ovacrs_regul_price_hour'] : 0;
    update_post_meta( $post_id, 'ovacrs_regul_price_hour', esc_attr( $ovacrs_regul_price_hour) );

    // save custom field
    $ovacrs_car_count = isset( $_POST['ovacrs_car_count'] ) ? $_POST['ovacrs_car_count'] : 0;
    update_post_meta( $post_id, 'ovacrs_car_count', esc_attr( $ovacrs_car_count ));

    $ovacrs_amount_insurance = isset( $_POST['ovacrs_amount_insurance'] ) ? $_POST['ovacrs_amount_insurance'] : 0;
    update_post_meta( $post_id, 'ovacrs_amount_insurance', esc_attr( $ovacrs_amount_insurance) );

    $ovacrs_car_order = isset( $_POST['ovacrs_car_order'] ) ? $_POST['ovacrs_car_order'] : 1;
    update_post_meta( $post_id, 'ovacrs_car_order', esc_attr( $ovacrs_car_order) );

    $ovacrs_id_vehicles = isset( $_POST['ovacrs_id_vehicles'] ) ? $_POST['ovacrs_id_vehicles'] : array();
    update_post_meta( $post_id, 'ovacrs_id_vehicles', $ovacrs_id_vehicles );

    $ovacrs_enable_deposit = isset( $_POST['ovacrs_enable_deposit'] ) ? $_POST['ovacrs_enable_deposit'] : 'no';
    update_post_meta( $post_id, 'ovacrs_enable_deposit', esc_attr( $ovacrs_enable_deposit) );

    $ovacrs_force_deposit = isset( $_POST['ovacrs_force_deposit'] ) ? $_POST['ovacrs_force_deposit'] : 'no';
    update_post_meta( $post_id, 'ovacrs_force_deposit', esc_attr( $ovacrs_force_deposit) );

    $ovacrs_type_deposit = isset( $_POST['ovacrs_type_deposit'] ) ? $_POST['ovacrs_type_deposit'] : 'percent';
    update_post_meta( $post_id, 'ovacrs_type_deposit', esc_attr( $ovacrs_type_deposit) );

    $ovacrs_amount_deposit = isset( $_POST['ovacrs_amount_deposit'] ) ? $_POST['ovacrs_amount_deposit'] : 0;
    update_post_meta( $post_id, 'ovacrs_amount_deposit', esc_attr( $ovacrs_amount_deposit) );

    $ovacrs_global_discount_price = isset( $_POST['ovacrs_global_discount_price'] ) ? $_POST['ovacrs_global_discount_price'] : '';
    update_post_meta( $post_id, 'ovacrs_global_discount_price', $ovacrs_global_discount_price );

    $ovacrs_global_discount_duration_val = isset( $_POST['ovacrs_global_discount_duration_val'] ) ? $_POST['ovacrs_global_discount_duration_val'] : '';
    update_post_meta( $post_id, 'ovacrs_global_discount_duration_val', $ovacrs_global_discount_duration_val );

    $ovacrs_global_discount_duration_type = isset( $_POST['ovacrs_global_discount_duration_type'] ) ? $_POST['ovacrs_global_discount_duration_type'] : '';
    update_post_meta( $post_id, 'ovacrs_global_discount_duration_type', $ovacrs_global_discount_duration_type );

    // Price/Day
    $ovacrs_rt_price = isset( $_POST['ovacrs_rt_price'] ) ? $_POST['ovacrs_rt_price'] : '';
    update_post_meta( $post_id, 'ovacrs_rt_price', $ovacrs_rt_price );

    // Price/Hour
    $ovacrs_rt_price_hour = isset( $_POST['ovacrs_rt_price_hour'] ) ? $_POST['ovacrs_rt_price_hour'] : '';
    update_post_meta( $post_id, 'ovacrs_rt_price_hour', $ovacrs_rt_price_hour );  

    $ovacrs_rt_startdate = isset( $_POST['ovacrs_rt_startdate'] ) ? $_POST['ovacrs_rt_startdate'] : '';
    update_post_meta( $post_id, 'ovacrs_rt_startdate', $ovacrs_rt_startdate );

    $ovacrs_rt_enddate = isset( $_POST['ovacrs_rt_enddate'] ) ? $_POST['ovacrs_rt_enddate'] : '';
    update_post_meta( $post_id, 'ovacrs_rt_enddate', $ovacrs_rt_enddate );

    $ovacrs_rt_discount = isset( $_POST['ovacrs_rt_discount'] ) ? $_POST['ovacrs_rt_discount'] : array();
    unset($ovacrs_rt_discount['ovacrs_key']);// Remove array has key is ovacrs_key 
    update_post_meta( $post_id, 'ovacrs_rt_discount', $ovacrs_rt_discount );

    $ovacrs_untime_startdate = isset( $_POST['ovacrs_untime_startdate'] ) ? $_POST['ovacrs_untime_startdate'] : '';
    update_post_meta( $post_id, 'ovacrs_untime_startdate', $ovacrs_untime_startdate );

    $ovacrs_untime_enddate = isset( $_POST['ovacrs_untime_enddate'] ) ? $_POST['ovacrs_untime_enddate'] : '';
    update_post_meta( $post_id, 'ovacrs_untime_enddate', $ovacrs_untime_enddate );

    $ovacrs_resource_name = isset( $_POST['ovacrs_resource_name'] ) ? $_POST['ovacrs_resource_name'] : '';
    update_post_meta( $post_id, 'ovacrs_resource_name', $ovacrs_resource_name );

    $ovacrs_resource_desc = isset( $_POST['ovacrs_resource_desc'] ) ? $_POST['ovacrs_resource_desc'] : '';
    update_post_meta( $post_id, 'ovacrs_resource_desc', $ovacrs_resource_desc );

    $ovacrs_resource_id = isset( $_POST['ovacrs_resource_id'] ) ? $_POST['ovacrs_resource_id'] : '';
    update_post_meta( $post_id, 'ovacrs_resource_id', $ovacrs_resource_id );

    $ovacrs_resource_price = isset( $_POST['ovacrs_resource_price'] ) ? $_POST['ovacrs_resource_price'] : '';
    update_post_meta( $post_id, 'ovacrs_resource_price', $ovacrs_resource_price );

    $ovacrs_resource_duration_type = isset( $_POST['ovacrs_resource_duration_type'] ) ? $_POST['ovacrs_resource_duration_type'] : '';
    update_post_meta( $post_id, 'ovacrs_resource_duration_type', $ovacrs_resource_duration_type );

    $ovacrs_rent_day_min = isset( $_POST['ovacrs_rent_day_min'] ) ? $_POST['ovacrs_rent_day_min'] : '';
    update_post_meta( $post_id, 'ovacrs_rent_day_min', $ovacrs_rent_day_min );

    $ovacrs_rent_hour_min = isset( $_POST['ovacrs_rent_hour_min'] ) ? $_POST['ovacrs_rent_hour_min'] : '';
    update_post_meta( $post_id, 'ovacrs_rent_hour_min', $ovacrs_rent_hour_min );

    $ovacrs_price_type = isset( $_POST['ovacrs_price_type'] ) ? $_POST['ovacrs_price_type'] : '';

    if ( !empty( $ovacrs_price_type ) ){
        update_post_meta( $post_id, 'ovacrs_price_type', $ovacrs_price_type );  
    } else {
        update_post_meta( $post_id, 'ovacrs_price_type', 'mixed' );  
    }

    $ovacrs_unfixed_time = isset( $_POST['ovacrs_unfixed_time'] ) ? $_POST['ovacrs_unfixed_time'] : '';
    update_post_meta( $post_id, 'ovacrs_unfixed_time', $ovacrs_unfixed_time );

    $ovacrs_features_desc = isset( $_POST['ovacrs_features_desc'] ) ? $_POST['ovacrs_features_desc'] : '';
    update_post_meta( $post_id, 'ovacrs_features_desc', $ovacrs_features_desc );

    $ovacrs_features_label = isset( $_POST['ovacrs_features_label'] ) ? $_POST['ovacrs_features_label'] : '';
    update_post_meta( $post_id, 'ovacrs_features_label', $ovacrs_features_label );

    $ovacrs_features_icons = isset( $_POST['ovacrs_features_icons'] ) ? $_POST['ovacrs_features_icons'] : '';
    update_post_meta( $post_id, 'ovacrs_features_icons', $ovacrs_features_icons );

    $ovacrs_features_special = isset( $_POST['ovacrs_features_special'] ) ? $_POST['ovacrs_features_special'] : '';
    update_post_meta( $post_id, 'ovacrs_features_special', $ovacrs_features_special );

    $ovacrs_other_features_name = isset( $_POST['ovacrs_other_features_name'] ) ? $_POST['ovacrs_other_features_name'] : '';
    update_post_meta( $post_id, 'ovacrs_other_features_name', $ovacrs_other_features_name );

    $ovacrs_video_link = isset( $_POST['ovacrs_video_link'] ) ? $_POST['ovacrs_video_link'] : '';
    update_post_meta( $post_id, 'ovacrs_video_link', $ovacrs_video_link );

    $ovacrs_pickup_location = isset( $_POST['ovacrs_pickup_location'] ) ? $_POST['ovacrs_pickup_location'] : '';
    update_post_meta( $post_id, 'ovacrs_pickup_location', $ovacrs_pickup_location );

    $ovacrs_dropoff_location = isset( $_POST['ovacrs_dropoff_location'] ) ? $_POST['ovacrs_dropoff_location'] : '';
    update_post_meta( $post_id, 'ovacrs_dropoff_location', $ovacrs_dropoff_location );

    $ovacrs_price_location = isset( $_POST['ovacrs_price_location'] ) ? $_POST['ovacrs_price_location'] : '';
    update_post_meta( $post_id, 'ovacrs_price_location', $ovacrs_price_location );

    $ovacrs_location_time = isset( $_POST['ovacrs_location_time'] ) ? $_POST['ovacrs_location_time'] : '';
    update_post_meta( $post_id, 'ovacrs_location_time', $ovacrs_location_time );

    $ovacrs_st_pickup_location = isset( $_POST['ovacrs_st_pickup_location'] ) ? $_POST['ovacrs_st_pickup_location'] : '';
    update_post_meta( $post_id, 'ovacrs_st_pickup_location', $ovacrs_st_pickup_location );

    $ovacrs_st_dropoff_location = isset( $_POST['ovacrs_st_dropoff_location'] ) ? $_POST['ovacrs_st_dropoff_location'] : '';
    update_post_meta( $post_id, 'ovacrs_st_dropoff_location', $ovacrs_st_dropoff_location );

    $ovacrs_location = isset( $_POST['ovacrs_location'] ) ? $_POST['ovacrs_location'] : '';
    update_post_meta( $post_id, 'ovacrs_location', $ovacrs_location );  

    $ovacrs_id_vehicles = isset( $_POST['ovacrs_id_vehicles'] ) ? $_POST['ovacrs_id_vehicles'] : '';
    update_post_meta( $post_id, 'ovacrs_id_vehicles', $ovacrs_id_vehicles );  

    $ovacrs_petime_price = isset( $_POST['ovacrs_petime_price'] ) ? $_POST['ovacrs_petime_price'] : '';
    update_post_meta( $post_id, 'ovacrs_petime_price', $ovacrs_petime_price );

    $ovacrs_petime_days = isset( $_POST['ovacrs_petime_days'] ) ? $_POST['ovacrs_petime_days'] : '';
    update_post_meta( $post_id, 'ovacrs_petime_days', $ovacrs_petime_days );

    $ovacrs_petime_id = isset( $_POST['ovacrs_petime_id'] ) ? $_POST['ovacrs_petime_id'] : '';
    update_post_meta( $post_id, 'ovacrs_petime_id', $ovacrs_petime_id );

    $ovacrs_petime_label  = isset( $_POST['ovacrs_petime_label'] ) ? $_POST['ovacrs_petime_label'] : '';
    update_post_meta( $post_id, 'ovacrs_petime_label', $ovacrs_petime_label );

    $ovacrs_petime_discount = isset( $_POST['ovacrs_petime_discount'] ) ? $_POST['ovacrs_petime_discount'] : array();
    unset($ovacrs_petime_discount['ovacrs_key']);// Remove array has key is ovacrs_key 
    update_post_meta( $post_id, 'ovacrs_petime_discount', $ovacrs_petime_discount );

    $ovacrs_package_type = isset( $_POST['ovacrs_package_type'] ) ? $_POST['ovacrs_package_type'] : '';
    update_post_meta( $post_id, 'ovacrs_package_type', $ovacrs_package_type );

    $ovacrs_pehour_start_time = isset( $_POST['ovacrs_pehour_start_time'] ) ? $_POST['ovacrs_pehour_start_time'] : '';
    update_post_meta( $post_id, 'ovacrs_pehour_start_time', $ovacrs_pehour_start_time );

    $ovacrs_pehour_end_time = isset( $_POST['ovacrs_pehour_end_time'] ) ? $_POST['ovacrs_pehour_end_time'] : '';
    update_post_meta( $post_id, 'ovacrs_pehour_end_time', $ovacrs_pehour_end_time );

    $ovacrs_pehour_unfixed = isset( $_POST['ovacrs_pehour_unfixed'] ) ? $_POST['ovacrs_pehour_unfixed'] : '';
    update_post_meta( $post_id, 'ovacrs_pehour_unfixed', $ovacrs_pehour_unfixed );

    $ovacrs_prepare_vehicle = isset( $_POST['ovacrs_prepare_vehicle'] ) ? $_POST['ovacrs_prepare_vehicle'] : '';
    update_post_meta( $post_id, 'ovacrs_prepare_vehicle', $ovacrs_prepare_vehicle );

    $ovacrs_contact_form_shortcode = isset( $_POST['ovacrs_contact_form_shortcode'] ) ? $_POST['ovacrs_contact_form_shortcode'] : '';
    update_post_meta( $post_id, 'ovacrs_contact_form_shortcode', $ovacrs_contact_form_shortcode );

    $ovacrs_manage_custom_checkout_field = isset( $_POST['ovacrs_manage_custom_checkout_field'] ) ? $_POST['ovacrs_manage_custom_checkout_field'] : '';
    update_post_meta( $post_id, 'ovacrs_manage_custom_checkout_field', $ovacrs_manage_custom_checkout_field );

    $ovacrs_product_custom_checkout_field = isset( $_POST['ovacrs_product_custom_checkout_field'] ) ? $_POST['ovacrs_product_custom_checkout_field'] : '';
    update_post_meta( $post_id, 'ovacrs_product_custom_checkout_field', $ovacrs_product_custom_checkout_field );
}
/******************************************************************************/